import { writable, type Writable } from 'svelte/store';

export const createStateStore = <T>() => {
  type State = {
    requests: T[];
  };

  const initialState: State = { requests: [] };
  const store: Writable<State> = writable(initialState);

  return {
    subscribe: store.subscribe,
    addRequest: (newRequest: T) => {
      store.update(state => ({
        ...state,
        requests: [...state.requests, newRequest]
      }));
    },
    reset: () => store.set(initialState),
  };
}

export type StateStore<T> = ReturnType<typeof createStateStore<T>>;
