import { API_URL } from '$env/static/private';
import { fail, redirect, type Actions } from '@sveltejs/kit';
import type { PageServerLoad } from './$types';

import { zod } from 'sveltekit-superforms/adapters';
import { setError, superValidate } from 'sveltekit-superforms/server';

import { handleRedirect } from '$lib/utils';
import { settingSchema } from '$lib/validations/auth';

export const load: PageServerLoad = async ({ url, locals: { user } }) => {
	if (!user) redirect(302, handleRedirect('login', url));

	const form = await superValidate(user, zod(settingSchema));

	return {
		title: 'Paramètres',
		form
	};
};

export const actions: Actions = {
	default: async ({ request, fetch, locals: { user } }) => {

		if (!user) return fail(401);

		const form = await superValidate(request, zod(settingSchema));

		if (!form.valid) {
			return fail(400, { form });
		}

		const res = await fetch(`${API_URL}/user/settings`, {
			method: 'POST',
			body: JSON.stringify({
				...form.data
			})
		});

		if (!res.ok) {
			if (res.status === 400) {
				return setError(form, "pseudo", "Ce pseudo est déjà utilisé");
			}
			return setError(form, "pseudo", "Une erreur est survenue lors de la sauvegarde des paramètres");
		}

		return {
			form
		};
	}
};
